<?php
/*
 * @version $Id: ldap.php 8025 2009-02-28 16:30:03Z moyo $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2009 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file: Walid Nouh
// Purpose of file:
// ----------------------------------------------------------------------

define('GLPI_ROOT', '..');
include (GLPI_ROOT . "/inc/includes.php");

checkSeveralRightsAnd(array("user"=>"w", "user_auth_method"=>"w"));

commonHeader($LANG['setup'][3],$_SERVER['PHP_SELF'],"admin","user","ldap");
if (isset($_SESSION["ldap_import"])) unset($_SESSION["ldap_import"]);
if (isset($_SESSION["ldap_sync"])) unset($_SESSION["ldap_sync"]);
if (isset($_SESSION["ldap_server"])) unset($_SESSION["ldap_server"]);
if (isset($_SESSION["ldap_sortorder"])) unset($_SESSION["ldap_sortorder"]);

echo "<div align='center'><table class='tab_cadre' cellpadding='5'>";
echo "<tr><th>".$LANG['ldap'][0]."</th></tr>";

echo "<tr class='tab_bg_1'><td  align='center'><a href=\"ldap.sync.php?next=listservers\"><b>".$LANG['ldap'][1]."</b></a></td></tr>";

echo "<tr class='tab_bg_1'><td align='center'><a href=\"ldap.import.php?next=listservers\"><b>".$LANG['ldap'][2]."</b></a></td> </tr>";

echo "</table></div>";

commonFooter();

?>
